@@ -4,9 +4,9 @@ from flask.cli import FlaskGroup
 from . import create_app_wsgi
 
 
-@click.group(cls=FlaskGroup, create_app=create_app_wsgi)
+@click.group(cls=FlaskGroup, create_app=create_app_wsgi,)
 def main():
-    """Management script for the hiddifypanel application."""
+    pass
 
 
 if __name__ == "__main__":  # pragma: no cover
